package solatium.interfaces;

import org.junit.Test;
import solatium.blockchain.BlockChain;
import solatium.blockchain.Chain;

import static org.junit.Assert.*;

public class CustomerTest {

    private static final Chain BLOCK_CHAIN = new BlockChain();

    @Test
    public void shouldIsBlocked() {
        User customer = new Customer("username", "password", "", 3, BLOCK_CHAIN);
        assertTrue(customer.isBlocked());
    }

    @Test
    public void shouldIsNotBlocked() {
        User customer = new Customer("username", "password", "", 0, BLOCK_CHAIN);
        assertFalse(customer.isBlocked());
    }

    @Test
    public void shouldAddErrorCounter() {
        User customer = new Customer("username", "password","", 0, BLOCK_CHAIN);
        assertEquals(1, customer.addErrorCounter());
    }

    @Test
    public void shouldGetErrorCounter() {
        User customer = new Customer("username", "password","", 0, BLOCK_CHAIN);
        assertEquals(0, customer.getErrorCounter());
        customer.addErrorCounter();
        assertEquals(1, customer.getErrorCounter());
    }

    @Test
    public void shouldUpdateBalance() {
        Chain blockChain = new BlockChain();
        User bank = new Bank(blockChain);
        User customer = new Customer("username", "password","xxx", 0, blockChain);
        assertEquals(0, customer.getBalance());
        bank.send("xxx", 100);
        assertEquals(100, customer.getBalance());
    }

    @Test(expected = NotEnoughMoneyException.class)
    public void shouldNotSendIfNotEnoughMoney() {
        User customer = new Customer("username", "password","xxx", 0, BLOCK_CHAIN);
        assertEquals(0, customer.getBalance());

        try {
            customer.send("foo", 100);
            fail();
        } catch (NotEnoughMoneyException e) {
            assertEquals("You don't have enough money to make that transaction", e.getMessage());
            throw e;
        }
    }
}